@@ -58,10 +58,9 @@ private:
     void readConfig();
 
     Ui::UrlConfigurationDialog mUi;
-    QStandardItemModel *mModel = nullptr;
+    QStandardItemModel *const mModel;
     QString mDefaultUsername;
     QString mDefaultPassword;
     QPushButton *mOkButton = nullptr;
     QButtonGroup *const mRemoteProtocolGroup;
 };
-
