@@ -11,7 +11,7 @@
 #include "googleresource.h"
 #include "googlesettings.h"
 
-#include <Akonadi/Calendar/BlockAlarmsAttribute>
+#include <Akonadi/BlockAlarmsAttribute>
 #include <Akonadi/CollectionColorAttribute>
 #include <Akonadi/CollectionModifyJob>
 #include <Akonadi/EntityDisplayAttribute>
@@ -322,7 +322,7 @@ FreeBusyHandler::FreeBusyHandler(GoogleResourceStateInterface *iface, GoogleSett
 
 QDateTime FreeBusyHandler::lastCacheUpdate() const
 {
-    return QDateTime();
+    return {};
 }
 
 void FreeBusyHandler::canHandleFreeBusy(const QString &email)
