@@ -16,10 +16,10 @@
 
 #include <KLocalizedString>
 
-#include <kimap/loginjob.h>
-#include <kimap/session.h>
-#include <kimap/subscribejob.h>
-#include <kimap/unsubscribejob.h>
+#include <KIMAP/LoginJob>
+#include <KIMAP/Session>
+#include <KIMAP/SubscribeJob>
+#include <KIMAP/UnsubscribeJob>
 
 #include "imapaccount.h"
 #include "sessionuiproxy.h"
@@ -27,10 +27,12 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 
+#include <KWindowConfig>
 #include <QHeaderView>
 #include <QLabel>
 #include <QTreeView>
 #include <QVBoxLayout>
+#include <QWindow>
 
 SubscriptionDialog::SubscriptionDialog(QWidget *parent, SubscriptionDialog::SubscriptionDialogOptions option)
     : QDialog(parent)
@@ -54,18 +56,18 @@ SubscriptionDialog::SubscriptionDialog(QWidget *parent, SubscriptionDialog::Subs
 
     auto mainWidget = new QWidget(this);
     auto mainLayout = new QVBoxLayout;
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
     mainWidget->setLayout(mainLayout);
     topLayout->addWidget(mainWidget);
     topLayout->addWidget(buttonBox);
 
-    m_enableSubscription = new QCheckBox(i18nc("@option:check", "Enable server-side subscriptions"));
+    m_enableSubscription = new QCheckBox(i18nc("@option:check", "Enable server-side subscriptions"), mainWidget);
     mainLayout->addWidget(m_enableSubscription);
 
     auto filterBarLayout = new QHBoxLayout;
     mainLayout->addLayout(filterBarLayout);
 
-    filterBarLayout->addWidget(new QLabel(i18nc("@label search for a subscription", "Search:")));
+    filterBarLayout->addWidget(new QLabel(i18nc("@label search for a subscription", "Search:"), mainWidget));
 
     m_lineEdit = new QLineEdit(mainWidget);
     m_lineEdit->setClearButtonEnabled(true);
@@ -74,7 +76,7 @@ SubscriptionDialog::SubscriptionDialog(QWidget *parent, SubscriptionDialog::Subs
     m_lineEdit->setFocus();
 
     auto checkBox = new QCheckBox(i18nc("@option:check", "Subscribed only"), mainWidget);
-    connect(checkBox, &QCheckBox::stateChanged, m_filter, QOverload<int>::of(&SubscriptionFilterProxyModel::setIncludeCheckedOnly));
+    connect(checkBox, &QCheckBox::stateChanged, m_filter, qOverload<int>(&SubscriptionFilterProxyModel::setIncludeCheckedOnly));
 
     filterBarLayout->addWidget(checkBox);
 
@@ -107,20 +109,17 @@ void SubscriptionDialog::slotSearchPattern(const QString &pattern)
 
 void SubscriptionDialog::readConfig()
 {
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(500, 300));
     KConfigGroup group(KSharedConfig::openStateConfig(), "SubscriptionDialog");
-
-    const QSize size = group.readEntry("Size", QSize());
-    if (size.isValid()) {
-        resize(size);
-    } else {
-        resize(500, 300);
-    }
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SubscriptionDialog::writeConfig()
 {
     KConfigGroup group(KSharedConfig::openStateConfig(), "SubscriptionDialog");
-    group.writeEntry("Size", size());
+    KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
 
